from setuptools import setup

setup(name='intro-distributions',
      version='0.1',
      description='Binomial and Gaussian distribution handling',
      packages=['distributions'],
      zip_safe=False)
